@@ -1,27 +1,30 @@
-use async_graphql::SimpleObject;
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize, SimpleObject)]
+#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
+#[cfg_attr(feature = "async-graphql", derive(async_graphql::SimpleObject))]
 #[serde(rename_all = "camelCase")]
 pub struct GetCandidateVotingRecordResponse {
     pub bills: Bills,
 }
 
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize, SimpleObject)]
+#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
+#[cfg_attr(feature = "async-graphql", derive(async_graphql::SimpleObject))]
 #[serde(rename_all = "camelCase")]
 pub struct Bills {
     pub general_info: GeneralInfo,
     pub bill: Vec<Bill>,
 }
 
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize, SimpleObject)]
+#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
+#[cfg_attr(feature = "async-graphql", derive(async_graphql::SimpleObject))]
 #[serde(rename_all = "camelCase")]
 pub struct GeneralInfo {
     pub title: String,
     pub link_back: String,
 }
 
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize, SimpleObject)]
+#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
+#[cfg_attr(feature = "async-graphql", derive(async_graphql::SimpleObject))]
 #[serde(rename_all = "camelCase")]
 pub struct Bill {
     pub bill_id: String,
@@ -37,7 +40,8 @@ pub struct Bill {
     pub vote: String,
 }
 
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize, SimpleObject)]
+#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
+#[cfg_attr(feature = "async-graphql", derive(async_graphql::SimpleObject))]
 #[serde(rename_all = "camelCase")]
 pub struct Categories {
     pub category: Value,
